@@ -105,8 +105,8 @@ presentation <- R6Class(
 
       if( !inherits(xml_list, "xml_missing")){
         xml_replace(xml_list, xml_elt)
-      } else{ ## needs to be after sldMasterIdLst...
-        xml_add_sibling(xml_find_first(private$doc, "//p:sldMasterIdLst"), xml_elt)
+      } else{ ## needs to be after all MasterIdLst elements. placing it before sldSz seems to be the safest option.
+        xml_add_sibling(xml_find_first(private$doc, "//p:sldSz"), xml_elt, .where = "before")
       }
 
       self
@@ -279,6 +279,24 @@ slide <- R6Class(
       }
       out
     },
+    get_location = function(type = NULL, index = 1){
+      out <- private$element_data
+      if( !is.null(type) ){
+        if( type %in% out$type ){
+          type_matches <- which( out$type == type )
+          if( index <= length(type_matches) )
+            id <- type_matches[index]
+          else stop(type, " can only have ", length(type_matches), " element(s) but index is set to ", index)
+
+        } else stop("type ", type, " is not available in the slide layout")
+        out <- out[id, ]
+      }
+
+      out[c("offx", "offy", "cx", "cy")] <- lapply( out[c("offx", "offy", "cx", "cy")], function(x) x / 914400 )
+      out <- out[c("offx", "offy", "cx", "cy", "ph_label", "type", "ph")]
+      names(out) <- c("left", "top", "width", "height", "ph_label", "type", "ph")
+      out
+    },
 
     layout_name = function(){
       private$layout_file
